==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/config/TList.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using com.db4o;

namespace com.db4o.config {

	/// <exclude />
    public class TList : ObjectTranslator {

        public void onActivate(ObjectContainer objectContainer, object obj, object members){
            IList list = (IList)obj;
            list.Clear();
            if(members != null){
                object[] elements = (object[]) members;
                for(int i = 0; i < elements.Length; i++){
                    list.Add(elements[i]);
                }
            }
        }

        public Object onStore(ObjectContainer objectContainer, object obj){
            IList list = (IList)obj;
            object[] elements = new object[list.Count];
            for(int i = 0; i < list.Count; i++){
                elements[i] = list[i];
            }
            return elements;
        }

        public Class storedClass(){
            return Class.getClassForType(typeof(object[]));
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/config/TList.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using com.db4o;

namespace com.db4o.config {

	/// <exclude />
    public class TList : ObjectTranslator {

        public void OnActivate(ObjectContainer objectContainer, object obj, object members){
            IList list = (IList)obj;
            list.Clear();
            if(members != null){
                object[] elements = (object[]) members;
                for(int i = 0; i < elements.Length; i++){
                    list.Add(elements[i]);
                }
            }
        }

        public Object OnStore(ObjectContainer objectContainer, object obj){
            IList list = (IList)obj;
            object[] elements = new object[list.Count];
            for(int i = 0; i < list.Count; i++){
                elements[i] = list[i];
            }
            return elements;
        }

        public Class StoredClass(){
            return Class.GetClassForType(typeof(object[]));
        }
    }
}
